@@ -3,8 +3,9 @@
 import boto3
 import pytest
 from botocore.exceptions import ClientError
+from freezegun import freeze_time
 
-from moto import mock_aws
+from moto import mock_aws, settings
 
 
 @mock_aws
@@ -259,6 +260,23 @@ def test_create_backup_vault():
     assert "BackupVaultArn" in resp
     assert "CreationDate" in resp
 
+    describe = client.describe_backup_vault(BackupVaultName="backupvault-foobar")
+    assert describe["BackupVaultName"] == "backupvault-foobar"
+    assert describe["BackupVaultArn"] == resp["BackupVaultArn"]
+
+
+@mock_aws
+def test_delete_backup_vault():
+    client = boto3.client("backup", region_name="eu-west-1")
+    client.create_backup_vault(BackupVaultName="backupvault-foobar")
+
+    client.delete_backup_vault(BackupVaultName="backupvault-foobar")
+
+    with pytest.raises(ClientError) as exc:
+        client.describe_backup_vault(BackupVaultName="backupvault-foobar")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+
 
 @mock_aws
 def test_create_backup_vault_already_exists():
@@ -358,3 +376,113 @@ def test_untag_resource():
     resp = client.untag_resource(ResourceArn=resource_arn, TagKeyList=["key2"])
     resp = client.list_tags(ResourceArn=resource_arn)
     assert resp["Tags"] == {"key1": "value1", "key3": "value3"}
+
+
+@mock_aws
+def test_put_backup_vault_lock_configuration():
+    client = boto3.client("backup", region_name="eu-west-1")
+    client.create_backup_vault(BackupVaultName="test-vault")
+
+    client.put_backup_vault_lock_configuration(
+        BackupVaultName="test-vault",
+        MinRetentionDays=7,
+        MaxRetentionDays=365,
+        ChangeableForDays=5,
+    )
+
+    resp = client.list_backup_vaults()
+    vault = resp["BackupVaultList"][0]
+    assert vault["Locked"] is True
+    assert vault["MinRetentionDays"] == 7
+    assert vault["MaxRetentionDays"] == 365
+    assert "LockDate" in vault
+
+    with pytest.raises(ClientError) as exc:
+        client.put_backup_vault_lock_configuration(
+            BackupVaultName="test-vault",
+            MinRetentionDays=100,
+            MaxRetentionDays=50,
+        )
+    assert exc.value.response["Error"]["Code"] == "InvalidParameterValueException"
+
+    with pytest.raises(ClientError) as exc:
+        client.put_backup_vault_lock_configuration(
+            BackupVaultName="test-vault",
+            MinRetentionDays=0,
+        )
+    assert exc.value.response["Error"]["Code"] == "InvalidParameterValueException"
+
+    with pytest.raises(ClientError) as exc:
+        client.put_backup_vault_lock_configuration(
+            BackupVaultName="test-vault",
+            MaxRetentionDays=36501,
+        )
+    assert exc.value.response["Error"]["Code"] == "InvalidParameterValueException"
+
+    with pytest.raises(ClientError) as exc:
+        client.put_backup_vault_lock_configuration(
+            BackupVaultName="test-vault",
+            ChangeableForDays=2,
+        )
+    assert exc.value.response["Error"]["Code"] == "InvalidParameterValueException"
+
+    with pytest.raises(ClientError) as exc:
+        client.put_backup_vault_lock_configuration(
+            BackupVaultName="nonexistent-vault",
+            MinRetentionDays=7,
+        )
+    assert exc.value.response["Error"]["Code"] == "ResourceNotFoundException"
+
+
+@mock_aws
+def test_delete_backup_vault_lock_configuration():
+    client = boto3.client("backup", region_name="eu-west-1")
+    client.create_backup_vault(BackupVaultName="test-vault")
+
+    client.put_backup_vault_lock_configuration(
+        BackupVaultName="test-vault",
+        MinRetentionDays=7,
+        MaxRetentionDays=365,
+    )
+
+    client.delete_backup_vault_lock_configuration(BackupVaultName="test-vault")
+
+    resp = client.list_backup_vaults()
+    vault = resp["BackupVaultList"][0]
+    assert vault.get("Locked", False) is False
+    assert "MinRetentionDays" not in vault
+
+    with pytest.raises(ClientError) as exc:
+        client.delete_backup_vault_lock_configuration(
+            BackupVaultName="nonexistent-vault",
+        )
+    assert exc.value.response["Error"]["Code"] == "ResourceNotFoundException"
+
+
+@pytest.mark.skipif(
+    settings.TEST_SERVER_MODE, reason="Can't freeze time in server mode"
+)
+@freeze_time("2024-01-01")
+@mock_aws
+def test_backup_vault_lock_immutable():
+    client = boto3.client("backup", region_name="eu-west-1")
+    client.create_backup_vault(BackupVaultName="test-vault")
+
+    client.put_backup_vault_lock_configuration(
+        BackupVaultName="test-vault",
+        MinRetentionDays=7,
+        ChangeableForDays=3,
+    )
+
+    # Fast forward past the lock date
+    with freeze_time("2024-01-05"):
+        with pytest.raises(ClientError) as exc:
+            client.delete_backup_vault_lock_configuration(BackupVaultName="test-vault")
+        assert exc.value.response["Error"]["Code"] == "InvalidRequestException"
+
+        with pytest.raises(ClientError) as exc:
+            client.put_backup_vault_lock_configuration(
+                BackupVaultName="test-vault",
+                MinRetentionDays=14,
+            )
+        assert exc.value.response["Error"]["Code"] == "InvalidRequestException"
