@@ -1,11 +1,11 @@
 import uuid
-from datetime import datetime
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
+from freezegun import freeze_time
 
-from moto import mock_databrew
+from moto import mock_aws
 
 
 def _create_databrew_client():
@@ -50,7 +50,7 @@ def _create_test_recipes(client, count):
         _create_test_recipe(client)
 
 
-@mock_databrew
+@mock_aws
 def test_recipe_list_when_empty():
     client = _create_databrew_client()
 
@@ -59,7 +59,7 @@ def test_recipe_list_when_empty():
     assert len(response["Recipes"]) == 0
 
 
-@mock_databrew
+@mock_aws
 def test_recipe_list_with_invalid_version():
     client = _create_databrew_client()
 
@@ -77,7 +77,7 @@ def test_recipe_list_with_invalid_version():
     assert err["Code"] == "ValidationException"
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipes_with_max_results():
     client = _create_databrew_client()
 
@@ -87,7 +87,7 @@ def test_list_recipes_with_max_results():
     assert "NextToken" in response
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipes_from_next_token():
     client = _create_databrew_client()
     _create_test_recipes(client, 10)
@@ -98,7 +98,7 @@ def test_list_recipes_from_next_token():
     assert len(response["Recipes"]) == 7
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipes_with_max_results_greater_than_actual_results():
     client = _create_databrew_client()
     _create_test_recipes(client, 4)
@@ -106,7 +106,7 @@ def test_list_recipes_with_max_results_greater_than_actual_results():
     assert len(response["Recipes"]) == 4
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipe_versions_no_recipe():
     client = _create_databrew_client()
     recipe_name = "NotExist"
@@ -114,7 +114,7 @@ def test_list_recipe_versions_no_recipe():
     assert len(response["Recipes"]) == 0
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipe_versions_none_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -123,7 +123,7 @@ def test_list_recipe_versions_none_published():
     assert len(response["Recipes"]) == 0
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipe_versions_one_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -134,7 +134,7 @@ def test_list_recipe_versions_one_published():
     assert response["Recipes"][0]["RecipeVersion"] == "1.0"
 
 
-@mock_databrew
+@mock_aws
 def test_list_recipe_versions_two_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -147,7 +147,7 @@ def test_list_recipe_versions_two_published():
     assert response["Recipes"][1]["RecipeVersion"] == "2.0"
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_latest_working():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -161,7 +161,35 @@ def test_describe_recipe_latest_working():
     assert recipe["RecipeVersion"] == "0.1"
 
 
-@mock_databrew
+@mock_aws
+def test_create_recipe_with_description_and_tags():
+    client = _create_databrew_client()
+    recipe_name = str(uuid.uuid4())
+    description = "Test recipe description"
+    tags = {"env": "test", "project": "moto"}
+
+    client.create_recipe(
+        Name=recipe_name,
+        Description=description,
+        Steps=[
+            {
+                "Action": {
+                    "Operation": "REMOVE_COMBINED",
+                    "Parameters": {"sourceColumn": "FakeColumn"},
+                }
+            }
+        ],
+        Tags=tags,
+    )
+
+    recipe = client.describe_recipe(Name=recipe_name, RecipeVersion="LATEST_WORKING")
+
+    assert recipe["Name"] == recipe_name
+    assert recipe["Description"] == description
+    assert recipe["Tags"] == tags
+
+
+@mock_aws
 @pytest.mark.parametrize("name", ["name", "name with space"])
 def test_describe_recipe_with_version(name):
     client = _create_databrew_client()
@@ -174,7 +202,7 @@ def test_describe_recipe_with_version(name):
     assert recipe["RecipeVersion"] == "0.1"
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_latest_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -189,7 +217,7 @@ def test_describe_recipe_latest_published():
     assert recipe["RecipeVersion"] == "1.0"
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_implicit_latest_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -202,7 +230,7 @@ def test_describe_recipe_implicit_latest_published():
     assert recipe["RecipeVersion"] == "1.0"
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_that_does_not_exist():
     client = _create_databrew_client()
 
@@ -217,7 +245,7 @@ def test_describe_recipe_that_does_not_exist():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_with_long_name():
     client = _create_databrew_client()
     name = "a" * 256
@@ -232,7 +260,7 @@ def test_describe_recipe_with_long_name():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_with_long_version():
     client = _create_databrew_client()
     version = "1" * 17
@@ -247,7 +275,7 @@ def test_describe_recipe_with_long_version():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 def test_describe_recipe_with_invalid_version():
     client = _create_databrew_client()
     name = "AnyName"
@@ -260,7 +288,7 @@ def test_describe_recipe_with_invalid_version():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 @pytest.mark.parametrize("name", ["name", "name with space"])
 def test_update_recipe(name):
     client = _create_databrew_client()
@@ -301,7 +329,7 @@ def test_update_recipe(name):
     assert recipe["Steps"][0]["Action"]["Parameters"]["removeCustomValue"] == "true"
 
 
-@mock_databrew
+@mock_aws
 def test_update_recipe_description():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -321,7 +349,7 @@ def test_update_recipe_description():
     assert recipe["Description"] == description
 
 
-@mock_databrew
+@mock_aws
 def test_update_recipe_invalid():
     client = _create_databrew_client()
 
@@ -334,7 +362,7 @@ def test_update_recipe_invalid():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_databrew
+@mock_aws
 def test_create_recipe_that_already_exists():
     client = _create_databrew_client()
 
@@ -348,7 +376,7 @@ def test_create_recipe_that_already_exists():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 409
 
 
-@mock_databrew
+@mock_aws
 @pytest.mark.parametrize("recipe_name", ["name", "name with space"])
 def test_publish_recipe(recipe_name):
     client = _create_databrew_client()
@@ -357,44 +385,60 @@ def test_publish_recipe(recipe_name):
 
     # Before a recipe is published, we should not be able to retrieve a published version
     with pytest.raises(ClientError) as exc:
-        recipe = client.describe_recipe(Name=recipe_name)
+        client.describe_recipe(Name=recipe_name)
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
 
-    dt_before_publish = datetime.now().astimezone()
+    with freeze_time("2024-01-15 12:00:00"):
+        # Publish the recipe
+        publish_response = client.publish_recipe(
+            Name=recipe_name, Description="1st desc"
+        )
+        assert publish_response["Name"] == recipe_name
 
-    # Publish the recipe
-    publish_response = client.publish_recipe(Name=recipe_name, Description="1st desc")
-    assert publish_response["Name"] == recipe_name
+        # Recipe is now published, so check we can retrieve the published version
+        recipe = client.describe_recipe(Name=recipe_name)
+        assert recipe["Description"] == "1st desc"
+        assert recipe["RecipeVersion"] == "1.0"
+        first_published_date = recipe["PublishedDate"]
 
-    # Recipe is now published, so check we can retrieve the published version
-    recipe = client.describe_recipe(Name=recipe_name)
-    assert recipe["Description"] == "1st desc"
-    assert recipe["RecipeVersion"] == "1.0"
-    assert recipe["PublishedDate"] > dt_before_publish
-    first_published_date = recipe["PublishedDate"]
+        # Latest Working should have created date == publish date
+        working_response = client.describe_recipe(
+            Name=recipe_name, RecipeVersion="LATEST_WORKING"
+        )
+        assert working_response["CreateDate"] == first_published_date
 
-    # Publish the recipe a 2nd time
-    publish_response = client.publish_recipe(Name=recipe_name, Description="2nd desc")
-    assert publish_response["Name"] == recipe_name
+    with freeze_time("2024-01-15 13:00:00"):
+        # Publish the recipe a 2nd time
+        publish_response = client.publish_recipe(
+            Name=recipe_name, Description="2nd desc"
+        )
+        assert publish_response["Name"] == recipe_name
 
-    recipe = client.describe_recipe(Name=recipe_name)
-    assert recipe["Description"] == "2nd desc"
-    assert recipe["RecipeVersion"] == "2.0"
-    assert recipe["PublishedDate"] >= first_published_date
+        recipe = client.describe_recipe(Name=recipe_name)
+        assert recipe["Description"] == "2nd desc"
+        assert recipe["RecipeVersion"] == "2.0"
+        assert recipe["PublishedDate"] > first_published_date
+
+        # Check working Created Date
+        working_response = client.describe_recipe(
+            Name=recipe_name, RecipeVersion="LATEST_WORKING"
+        )
+        assert recipe["PublishedDate"] == working_response["CreateDate"]
 
 
-@mock_databrew
+@mock_aws
 def test_publish_recipe_that_does_not_exist():
     client = _create_databrew_client()
     with pytest.raises(ClientError) as exc:
         client.publish_recipe(Name="DoesNotExist")
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == "Recipe DoesNotExist wasn't found"
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_databrew
+@mock_aws
 def test_publish_long_recipe_name():
     client = _create_databrew_client()
     name = "a" * 256
@@ -411,7 +455,7 @@ def test_publish_long_recipe_name():
     assert err["Code"] == "ValidationException"
 
 
-@mock_databrew
+@mock_aws
 @pytest.mark.parametrize("recipe_name", ["name", "name with space"])
 def test_delete_recipe_version(recipe_name):
     client = _create_databrew_client()
@@ -425,7 +469,7 @@ def test_delete_recipe_version(recipe_name):
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_published():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -441,7 +485,7 @@ def test_delete_recipe_version_published():
     assert recipe["RecipeVersion"] == "1.1"
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_latest_working_after_publish():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -457,7 +501,7 @@ def test_delete_recipe_version_latest_working_after_publish():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_latest_working_numeric_after_publish():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -471,7 +515,7 @@ def test_delete_recipe_version_latest_working_numeric_after_publish():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_invalid_version_string():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -488,7 +532,23 @@ def test_delete_recipe_version_invalid_version_string():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
+def test_delete_recipe_version_latest_published_not_allowed():
+    client = _create_databrew_client()
+    response = _create_test_recipe(client)
+    recipe_name = response["Name"]
+    client.publish_recipe(Name=recipe_name)
+    with pytest.raises(ClientError) as exc:
+        client.delete_recipe_version(Name=recipe_name, RecipeVersion="LATEST_PUBLISHED")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"] == f"Recipe {recipe_name} version LATEST_PUBLISHED is invalid."
+    )
+    assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
+
+
+@mock_aws
 def test_delete_recipe_version_invalid_version_length():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
@@ -505,7 +565,7 @@ def test_delete_recipe_version_invalid_version_length():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_unknown_recipe():
     client = _create_databrew_client()
     recipe_name = "Unknown"
@@ -517,7 +577,7 @@ def test_delete_recipe_version_unknown_recipe():
     assert exc.value.response["ResponseMetadata"]["HTTPStatusCode"] == 404
 
 
-@mock_databrew
+@mock_aws
 def test_delete_recipe_version_unknown_version():
     client = _create_databrew_client()
     response = _create_test_recipe(client)
