@@ -8,7 +8,7 @@ from botocore.exceptions import ClientError
 
 from moto import mock_aws, settings
 
-from .helpers import check_private_key
+from .helpers import assert_dryrun_error, check_private_key
 
 ED25519_PUBLIC_KEY_OPENSSH = b"""\
 ssh-ed25519 \
@@ -116,12 +116,7 @@ def test_key_pairs_create_dryrun():
 
     with pytest.raises(ClientError) as ex:
         ec2.create_key_pair(KeyName="foo", DryRun=True)
-    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
-    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
-    assert (
-        ex.value.response["Error"]["Message"]
-        == "An error occurred (DryRunOperation) when calling the CreateKeyPair operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(ex)
 
 
 @mock_aws
@@ -173,7 +168,9 @@ def test_key_pairs_create_exist():
 @mock_aws
 def test_key_pairs_delete_no_exist():
     client = boto3.client("ec2", "us-west-1")
-    client.delete_key_pair(KeyName=str(uuid4())[0:6])
+    resp = client.delete_key_pair(KeyName=str(uuid4())[0:6])
+    assert resp["Return"] is True
+    assert "KeyPairId" not in resp
 
 
 @mock_aws
@@ -184,12 +181,7 @@ def test_key_pairs_delete_exist():
 
     with pytest.raises(ClientError) as ex:
         client.delete_key_pair(KeyName=key_name, DryRun=True)
-    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
-    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
-    assert (
-        ex.value.response["Error"]["Message"]
-        == "An error occurred (DryRunOperation) when calling the DeleteKeyPair operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(ex)
 
     client.delete_key_pair(KeyName=key_name)
     assert key_name not in [
@@ -199,14 +191,14 @@ def test_key_pairs_delete_exist():
 
 @mock_aws
 @pytest.mark.parametrize(
-    "public_key,fingerprint",
+    "public_key,fingerprint,key_type",
     [
-        (RSA_PUBLIC_KEY_OPENSSH, RSA_PUBLIC_KEY_FINGERPRINT),
-        (RSA_PUBLIC_KEY_RFC4716_1, RSA_PUBLIC_KEY_FINGERPRINT),
-        (RSA_PUBLIC_KEY_RFC4716_2, RSA_PUBLIC_KEY_FINGERPRINT),
-        (RSA_PUBLIC_KEY_RFC4716_3, RSA_PUBLIC_KEY_FINGERPRINT),
-        (RSA_PUBLIC_KEY_RFC4716_4, RSA_PUBLIC_KEY_FINGERPRINT),
-        (ED25519_PUBLIC_KEY_OPENSSH, ED25519_PUBLIC_KEY_FINGERPRINT),
+        (RSA_PUBLIC_KEY_OPENSSH, RSA_PUBLIC_KEY_FINGERPRINT, "rsa"),
+        (RSA_PUBLIC_KEY_RFC4716_1, RSA_PUBLIC_KEY_FINGERPRINT, "rsa"),
+        (RSA_PUBLIC_KEY_RFC4716_2, RSA_PUBLIC_KEY_FINGERPRINT, "rsa"),
+        (RSA_PUBLIC_KEY_RFC4716_3, RSA_PUBLIC_KEY_FINGERPRINT, "rsa"),
+        (RSA_PUBLIC_KEY_RFC4716_4, RSA_PUBLIC_KEY_FINGERPRINT, "rsa"),
+        (ED25519_PUBLIC_KEY_OPENSSH, ED25519_PUBLIC_KEY_FINGERPRINT, "ed25519"),
     ],
     ids=[
         "rsa-openssh",
@@ -217,7 +209,7 @@ def test_key_pairs_delete_exist():
         "ed25519",
     ],
 )
-def test_key_pairs_import(public_key, fingerprint):
+def test_key_pairs_import(public_key, fingerprint, key_type):
     client = boto3.client("ec2", "us-west-1")
 
     key_name = str(uuid4())[0:6]
@@ -225,12 +217,7 @@ def test_key_pairs_import(public_key, fingerprint):
         client.import_key_pair(
             KeyName=key_name, PublicKeyMaterial=public_key, DryRun=True
         )
-    assert ex.value.response["Error"]["Code"] == "DryRunOperation"
-    assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 412
-    assert (
-        ex.value.response["Error"]["Message"]
-        == "An error occurred (DryRunOperation) when calling the ImportKeyPair operation: Request would have succeeded, but DryRun flag is set"
-    )
+    assert_dryrun_error(ex)
 
     kp1 = client.import_key_pair(KeyName=key_name, PublicKeyMaterial=public_key)
 
@@ -238,9 +225,22 @@ def test_key_pairs_import(public_key, fingerprint):
     assert kp1["KeyName"] == key_name
     assert kp1["KeyFingerprint"] == fingerprint
 
-    all_kps = client.describe_key_pairs()["KeyPairs"]
-    all_names = [kp["KeyName"] for kp in all_kps]
-    assert kp1["KeyName"] in all_names
+    resp = client.describe_key_pairs(
+        Filters=[{"Name": "key-pair-id", "Values": [kp1["KeyPairId"]]}]
+    )
+    key_pair = resp["KeyPairs"][0]
+    assert key_pair["KeyPairId"] == kp1["KeyPairId"]
+    assert key_pair["KeyFingerprint"] == kp1["KeyFingerprint"]
+    assert key_pair["KeyName"] == kp1["KeyName"]
+    assert key_pair["KeyType"] == key_type
+    assert "PublicKey" not in key_pair
+
+    resp = client.describe_key_pairs(
+        IncludePublicKey=True,
+        Filters=[{"Name": "key-pair-id", "Values": [kp1["KeyPairId"]]}],
+    )
+    key_pair = resp["KeyPairs"][0]
+    assert key_pair["PublicKey"] == public_key.decode("utf-8")
 
 
 @mock_aws
