@@ -5,11 +5,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as OWNER_ID
 
 
-@mock_ec2
+@mock_aws
 def test_default_network_acl_created_with_vpc():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -21,7 +21,7 @@ def test_default_network_acl_created_with_vpc():
     assert our_acl[0]["IsDefault"] is True
 
 
-@mock_ec2
+@mock_aws
 def test_network_create_and_list_acls():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -38,7 +38,7 @@ def test_network_create_and_list_acls():
     assert acl_found["IsDefault"] is False
 
 
-@mock_ec2
+@mock_aws
 def test_new_subnet_associates_with_default_network_acl():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("ServerMode will have conflicting CidrBlocks")
@@ -55,7 +55,7 @@ def test_new_subnet_associates_with_default_network_acl():
     assert subnet.id in [a["SubnetId"] for a in acl["Associations"]]
 
 
-@mock_ec2
+@mock_aws
 def test_network_acl_entries():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -69,6 +69,7 @@ def test_network_acl_entries():
         Protocol="6",  # TCP
         RuleAction="ALLOW",
         CidrBlock="0.0.0.0/0",
+        Ipv6CidrBlock="asdf",
         Egress=False,
         PortRange={"From": 443, "To": 443},
     )
@@ -88,9 +89,10 @@ def test_network_acl_entries():
     assert entries[0]["Egress"] is False
     assert entries[0]["PortRange"] == {"To": 443, "From": 443}
     assert entries[0]["CidrBlock"] == "0.0.0.0/0"
+    assert entries[0]["Ipv6CidrBlock"] == "asdf"
 
 
-@mock_ec2
+@mock_aws
 def test_delete_network_acl_entry():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -119,7 +121,7 @@ def test_delete_network_acl_entry():
     assert len(test_network_acl["Entries"]) == 0
 
 
-@mock_ec2
+@mock_aws
 def test_replace_network_acl_entry():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -159,7 +161,7 @@ def test_replace_network_acl_entry():
     assert entries[0]["PortRange"] == {"To": 22, "From": 22}
 
 
-@mock_ec2
+@mock_aws
 def test_delete_network_acl():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -182,7 +184,7 @@ def test_delete_network_acl():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_network_acl_tagging():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -205,7 +207,7 @@ def test_network_acl_tagging():
     assert test_network_acl["Tags"] == [{"Value": "some value", "Key": "a key"}]
 
 
-@mock_ec2
+@mock_aws
 def test_new_subnet_in_new_vpc_associates_with_default_network_acl():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     new_vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -221,7 +223,7 @@ def test_new_subnet_in_new_vpc_associates_with_default_network_acl():
     assert new_vpcs_default_network_acl.associations[0]["SubnetId"] == subnet.id
 
 
-@mock_ec2
+@mock_aws
 def test_default_network_acl_default_entries():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -260,7 +262,7 @@ def test_default_network_acl_default_entries():
     assert len(unique_entries) == 4
 
 
-@mock_ec2
+@mock_aws
 def test_delete_default_network_acl_default_entry():
     if settings.TEST_SERVER_MODE:
         raise SkipTest(
@@ -281,7 +283,7 @@ def test_delete_default_network_acl_default_entry():
     assert len(default_network_acl.entries) == 3
 
 
-@mock_ec2
+@mock_aws
 def test_duplicate_network_acl_entry():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     default_network_acl = next(iter(ec2.network_acls.all()), None)
@@ -311,7 +313,7 @@ def test_duplicate_network_acl_entry():
     )
 
 
-@mock_ec2
+@mock_aws
 def test_describe_network_acls():
     conn = boto3.client("ec2", region_name="us-west-2")
 
@@ -421,7 +423,118 @@ def test_describe_network_acls():
     )
 
 
-@mock_ec2
+@mock_aws
+def test_describe_network_acls_associations_by_acl_id():
+    ec2_client = boto3.client("ec2", region_name="us-west-2")
+    vpc_id = ec2_client.create_vpc(CidrBlock="10.0.0.0/16")["Vpc"]["VpcId"]
+    subnet = ec2_client.create_subnet(VpcId=vpc_id, CidrBlock="10.0.1.0/24")
+    subnet_id = subnet["Subnet"]["SubnetId"]
+    custom_acl = ec2_client.create_network_acl(VpcId=vpc_id)["NetworkAcl"]
+    associate_subnet_to_acl(ec2_client, subnet_id, custom_acl["NetworkAclId"])
+
+    network_acls_by_subnet = ec2_client.describe_network_acls(
+        Filters=[{"Name": "association.subnet-id", "Values": [subnet_id]}]
+    )["NetworkAcls"]
+    association_id = network_acls_by_subnet[0]["Associations"][0][
+        "NetworkAclAssociationId"
+    ]
+
+    network_acls_by_association = ec2_client.describe_network_acls(
+        Filters=[{"Name": "association.association-id", "Values": [association_id]}]
+    )["NetworkAcls"]
+    assert len(network_acls_by_association) == 1
+    assert network_acls_by_association[0]["NetworkAclId"] == custom_acl["NetworkAclId"]
+
+
+@mock_aws
+def test_describe_network_acls_associations_by_subnet():
+    ec2_client = boto3.client("ec2", region_name="us-west-2")
+    vpc = ec2_client.create_vpc(CidrBlock="10.0.0.0/16")
+    vpc_id = vpc["Vpc"]["VpcId"]
+    all_acls = ec2_client.describe_network_acls(
+        Filters=[{"Name": "vpc-id", "Values": [vpc_id]}]
+    )["NetworkAcls"]
+    subnet_1_id = ec2_client.create_subnet(VpcId=vpc_id, CidrBlock="10.0.1.0/24")[
+        "Subnet"
+    ]["SubnetId"]
+    subnet_2_id = ec2_client.create_subnet(VpcId=vpc_id, CidrBlock="10.0.2.0/24")[
+        "Subnet"
+    ]["SubnetId"]
+    subnet_3_id = ec2_client.create_subnet(VpcId=vpc_id, CidrBlock="10.0.3.0/24")[
+        "Subnet"
+    ]["SubnetId"]
+    default_acl_id = next(acl["NetworkAclId"] for acl in all_acls if acl["IsDefault"])
+    custom_acl_id = ec2_client.create_network_acl(VpcId=vpc_id)["NetworkAcl"][
+        "NetworkAclId"
+    ]
+
+    # Subnets should be associated with the default ACL by default
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_1_id, default_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_3_id, default_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_2_id, default_acl_id)
+
+    associate_subnet_to_acl(ec2_client, subnet_1_id, custom_acl_id)
+    associate_subnet_to_acl(ec2_client, subnet_3_id, custom_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_1_id, custom_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_3_id, custom_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_2_id, default_acl_id)
+
+    # Re-associate Subnet 1 with the default ACL to test re-association
+    associate_subnet_to_acl(ec2_client, subnet_1_id, default_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_1_id, default_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_2_id, default_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_3_id, custom_acl_id)
+
+    # Attempting to associate a non-existent ACL with a subnet should raise an error
+    with pytest.raises(ClientError):
+        associate_subnet_to_acl(ec2_client, subnet_1_id, "non-existent-acl")
+
+    # Attempting to delete a custom network ACL should fail if it has any subnets associated
+    with pytest.raises(ClientError) as exc:
+        ec2_client.delete_network_acl(NetworkAclId=custom_acl_id)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "DependencyViolation"
+    assert (
+        err["Message"]
+        == f"The network ACL '{custom_acl_id}' has dependencies and cannot be deleted."
+    )
+
+    # Re-associate Subnet 3 with the default ACL to test deletion of custom ACL
+    associate_subnet_to_acl(ec2_client, subnet_3_id, default_acl_id)
+    ec2_client.delete_network_acl(NetworkAclId=custom_acl_id)
+    assert_subnet_is_associated_to_acl(ec2_client, subnet_3_id, default_acl_id)
+
+
+def associate_subnet_to_acl(ec2_client, subnet_id: str, acl_id: str):
+    assoc_id = get_subnet_acl_association_id(ec2_client, subnet_id)
+    ec2_client.replace_network_acl_association(
+        NetworkAclId=acl_id, AssociationId=assoc_id
+    )
+
+
+def get_subnet_acl_association_id(ec2_client, subnet_id: str):
+    network_acls_description = ec2_client.describe_network_acls(
+        Filters=[{"Name": "association.subnet-id", "Values": [subnet_id]}]
+    )
+    associations = network_acls_description["NetworkAcls"][0]["Associations"]
+    return next(
+        assoc["NetworkAclAssociationId"]
+        for assoc in associations
+        if assoc["SubnetId"] == subnet_id
+    )
+
+
+def assert_subnet_is_associated_to_acl(ec2_client, subnet_id: str, acl_id: str):
+    network_acl_description = ec2_client.describe_network_acls(
+        Filters=[{"Name": "association.subnet-id", "Values": [subnet_id]}]
+    )
+    acls_subnet = network_acl_description["NetworkAcls"]
+    # There should be only one ACL associated with the subnet at any given time
+    assert len(acls_subnet) == 1
+    assert acls_subnet[0]["NetworkAclId"] == acl_id
+
+
+@mock_aws
 def test_create_network_acl_with_tags():
     conn = boto3.client("ec2", region_name="us-west-2")
 
