@@ -32,18 +32,22 @@ def test_iot_list():
 def test_list_attached_policies(url_encode_arn):
     backend = server.create_backend_app("iot")
     test_client = backend.test_client()
-
-    result = test_client.post("/keys-and-certificate?setAsActive=true")
+    headers = {"Content-Type": "application/json"}
+    result = test_client.post("/keys-and-certificate?setAsActive=true", headers=headers)
     result_dict = json.loads(result.data.decode("utf-8"))
     certificate_arn = result_dict["certificateArn"]
 
-    test_client.post("/policies/my-policy", json={"policyDocument": {}})
-    test_client.put("/target-policies/my-policy", json={"target": certificate_arn})
+    test_client.post(
+        "/policies/my-policy", json={"policyDocument": {}}, headers=headers
+    )
+    test_client.put(
+        "/target-policies/my-policy", json={"target": certificate_arn}, headers=headers
+    )
 
     if url_encode_arn:
         certificate_arn = quote(certificate_arn, safe="")
 
-    result = test_client.post(f"/attached-policies/{certificate_arn}")
+    result = test_client.post(f"/attached-policies/{certificate_arn}", headers=headers)
     assert result.status_code == 200
     result_dict = json.loads(result.data.decode("utf-8"))
     assert result_dict["policies"][0]["policyName"] == "my-policy"
