@@ -1,11 +1,9 @@
-from datetime import datetime
-from typing import List
+from datetime import datetime, timezone
 from unittest import SkipTest
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
-from dateutil.tz import tzutc
 from freezegun import freeze_time
 
 from moto import mock_aws, settings
@@ -106,7 +104,7 @@ def test_describe_device() -> None:
         resp["Arn"] == "arn:aws:panorama:eu-west-1:123456789012:device/test-device-name"
     )
     assert resp["Brand"] == "AWS_PANORAMA"
-    assert resp["CreatedTime"] == datetime(2020, 1, 1, 12, 0, tzinfo=tzutc())
+    assert resp["CreatedTime"] == datetime(2020, 1, 1, 12, 0, tzinfo=timezone.utc)
     assert resp["CurrentNetworkingStatus"] == {
         "Ethernet0Status": {
             "ConnectionStatus": "CONNECTED",
@@ -118,7 +116,7 @@ def test_describe_device() -> None:
             "HwAddress": "8C:0F:6F:60:F4:F1",
             "IpAddress": "--",
         },
-        "LastUpdatedTime": datetime(2020, 1, 1, 12, 0, tzinfo=tzutc()),
+        "LastUpdatedTime": datetime(2020, 1, 1, 12, 0, tzinfo=timezone.utc),
         "NtpStatus": {
             "ConnectionStatus": "CONNECTED",
             "IpAddress": "91.224.149.41:123",
@@ -132,7 +130,9 @@ def test_describe_device() -> None:
     assert resp["DeviceId"] == "device-RsozEWjZpeNe3SXHidX3mg"
     assert resp["LatestDeviceJob"] == {"JobType": "REBOOT", "Status": "COMPLETED"}
     assert resp["LatestSoftware"] == "6.2.1"
-    assert resp["LeaseExpirationTime"] == datetime(2020, 1, 6, 12, 0, tzinfo=tzutc())
+    assert resp["LeaseExpirationTime"] == datetime(
+        2020, 1, 6, 12, 0, tzinfo=timezone.utc
+    )
     assert resp["Name"] == "test-device-name"
     assert resp["ProvisioningStatus"] == "SUCCEEDED"
     assert resp["SerialNumber"] == "GAD81E29013274749"
@@ -315,7 +315,7 @@ def test_list_device_max_result_and_next_token() -> None:
     ],
 )
 @mock_aws
-def test_list_devices_sort_order(sort_order: str, indexes: List[int]) -> None:
+def test_list_devices_sort_order(sort_order: str, indexes: list[int]) -> None:
     client = boto3.client("panorama", region_name="eu-west-1")
     resp_1 = client.provision_device(
         Description="test device description 1",
@@ -345,7 +345,7 @@ def test_list_devices_sort_order(sort_order: str, indexes: List[int]) -> None:
     ],
 )
 @mock_aws
-def test_list_devices_sort_by(sort_by: str, indexes: List[int]) -> None:
+def test_list_devices_sort_by(sort_by: str, indexes: list[int]) -> None:
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Can't freeze time in ServerMode")
     client = boto3.client("panorama", region_name="eu-west-1")
