@@ -535,56 +535,6 @@ def test_get_tag_values_event_bus():
     ]
 
 
-@mock_aws
-def test_get_tag_values_cloudfront():
-    client = boto3.client("cloudfront", "us-east-1")
-    for i in range(1, 3):
-        caller_reference = f"distribution{i}"
-        origin_id = f"origin{i}"
-
-        client.create_distribution_with_tags(
-            DistributionConfigWithTags={
-                "DistributionConfig": {
-                    "CallerReference": caller_reference,
-                    "Origins": {
-                        "Quantity": 1,
-                        "Items": [
-                            {
-                                "Id": origin_id,
-                                "DomainName": "example-bucket.s3.amazonaws.com",
-                                "S3OriginConfig": {"OriginAccessIdentity": ""},
-                            }
-                        ],
-                    },
-                    "DefaultCacheBehavior": {
-                        "TargetOriginId": origin_id,
-                        "ViewerProtocolPolicy": "allow-all",
-                        "TrustedSigners": {"Enabled": False, "Quantity": 0},
-                        "ForwardedValues": {
-                            "QueryString": False,
-                            "Cookies": {"Forward": "none"},
-                        },
-                        "MinTTL": 0,
-                    },
-                    "Comment": f"Sample distribution {i}",
-                    "Enabled": True,
-                },
-                "Tags": {"Items": [{"Key": "Test", "Value": f"Test{i}"}]},
-            }
-        )
-    rtapi = boto3.client("resourcegroupstaggingapi", "us-east-1")
-
-    # Test tag filtering
-    resp = rtapi.get_resources(
-        ResourceTypeFilters=["cloudfront"],
-        TagFilters=[{"Key": "Test", "Values": ["Test1"]}],
-    )
-    assert len(resp["ResourceTagMappingList"]) == 1
-    assert {"Key": "Test", "Value": "Test1"} in resp["ResourceTagMappingList"][0][
-        "Tags"
-    ]
-
-
 @mock_aws
 def test_get_tag_values_lexv2_models():
     client = boto3.client("lexv2-models", "us-east-1")
