@@ -1,4 +1,3 @@
-import sure  # noqa # pylint: disable=unused-import
 import xmltodict
 
 import moto.server as server
@@ -22,7 +21,7 @@ def test_list_recordset():
     # list record set
     res = test_client.get(f"2013-04-01/hostedzone/{zone_id}/rrset")
     # Ampersand should be properly encoded
-    res.data.decode("utf-8").should.contain("<Value><![CDATA[val&sth]]></Value>")
+    assert "<Value><![CDATA[val&sth]]></Value>" in res.data.decode("utf-8")
 
 
 def parse_xml(body):
