@@ -1,16 +1,17 @@
 import json
 import re
+from uuid import uuid4
 
 import boto3
 
-from moto import mock_cloudformation, mock_s3
+from moto import mock_aws
 
 
-@mock_s3
-@mock_cloudformation
+@mock_aws
 def test_s3_bucket_cloudformation_basic():
     s3_client = boto3.client("s3", region_name="us-east-1")
     cf_client = boto3.client("cloudformation", region_name="us-east-1")
+    stack_name = str(uuid4())
 
     template = {
         "AWSTemplateFormatVersion": "2010-09-09",
@@ -18,19 +19,19 @@ def test_s3_bucket_cloudformation_basic():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.create_stack(StackName="test_stack", TemplateBody=template_json)
-    stack_description = cf_client.describe_stacks(StackName="test_stack")["Stacks"][0]
+    cf_client.create_stack(StackName=stack_name, TemplateBody=template_json)
+    stack_description = cf_client.describe_stacks(StackName=stack_name)["Stacks"][0]
 
     s3_client.head_bucket(Bucket=stack_description["Outputs"][0]["OutputValue"])
 
 
-@mock_s3
-@mock_cloudformation
+@mock_aws
 def test_s3_bucket_cloudformation_with_properties():
     s3_client = boto3.client("s3", region_name="us-east-1")
     cf_client = boto3.client("cloudformation", region_name="us-east-1")
+    stack_name = str(uuid4())
 
-    bucket_name = "MyBucket"
+    bucket_name = str(uuid4())
     template = {
         "AWSTemplateFormatVersion": "2010-09-09",
         "Resources": {
@@ -53,8 +54,8 @@ def test_s3_bucket_cloudformation_with_properties():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.create_stack(StackName="test_stack", TemplateBody=template_json)
-    cf_client.describe_stacks(StackName="test_stack")
+    cf_client.create_stack(StackName=stack_name, TemplateBody=template_json)
+    cf_client.describe_stacks(StackName=stack_name)
     s3_client.head_bucket(Bucket=bucket_name)
 
     encryption = s3_client.get_bucket_encryption(Bucket=bucket_name)
@@ -66,11 +67,11 @@ def test_s3_bucket_cloudformation_with_properties():
     )
 
 
-@mock_s3
-@mock_cloudformation
+@mock_aws
 def test_s3_bucket_cloudformation_update_no_interruption():
     s3_client = boto3.client("s3", region_name="us-east-1")
     cf_client = boto3.client("cloudformation", region_name="us-east-1")
+    stack_name = str(uuid4())
 
     template = {
         "AWSTemplateFormatVersion": "2010-09-09",
@@ -78,8 +79,8 @@ def test_s3_bucket_cloudformation_update_no_interruption():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.create_stack(StackName="test_stack", TemplateBody=template_json)
-    stack_description = cf_client.describe_stacks(StackName="test_stack")["Stacks"][0]
+    cf_client.create_stack(StackName=stack_name, TemplateBody=template_json)
+    stack_description = cf_client.describe_stacks(StackName=stack_name)["Stacks"][0]
     s3_client.head_bucket(Bucket=stack_description["Outputs"][0]["OutputValue"])
 
     template = {
@@ -103,7 +104,7 @@ def test_s3_bucket_cloudformation_update_no_interruption():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.update_stack(StackName="test_stack", TemplateBody=template_json)
+    cf_client.update_stack(StackName=stack_name, TemplateBody=template_json)
     encryption = s3_client.get_bucket_encryption(
         Bucket=stack_description["Outputs"][0]["OutputValue"]
     )
@@ -115,11 +116,11 @@ def test_s3_bucket_cloudformation_update_no_interruption():
     )
 
 
-@mock_s3
-@mock_cloudformation
+@mock_aws
 def test_s3_bucket_cloudformation_update_replacement():
     s3_client = boto3.client("s3", region_name="us-east-1")
     cf_client = boto3.client("cloudformation", region_name="us-east-1")
+    stack_name = str(uuid4())
 
     template = {
         "AWSTemplateFormatVersion": "2010-09-09",
@@ -127,8 +128,8 @@ def test_s3_bucket_cloudformation_update_replacement():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.create_stack(StackName="test_stack", TemplateBody=template_json)
-    stack_description = cf_client.describe_stacks(StackName="test_stack")["Stacks"][0]
+    cf_client.create_stack(StackName=stack_name, TemplateBody=template_json)
+    stack_description = cf_client.describe_stacks(StackName=stack_name)["Stacks"][0]
     s3_client.head_bucket(Bucket=stack_description["Outputs"][0]["OutputValue"])
 
     template = {
@@ -142,19 +143,18 @@ def test_s3_bucket_cloudformation_update_replacement():
         "Outputs": {"Bucket": {"Value": {"Ref": "testInstance"}}},
     }
     template_json = json.dumps(template)
-    cf_client.update_stack(StackName="test_stack", TemplateBody=template_json)
-    stack_description = cf_client.describe_stacks(StackName="test_stack")["Stacks"][0]
+    cf_client.update_stack(StackName=stack_name, TemplateBody=template_json)
+    stack_description = cf_client.describe_stacks(StackName=stack_name)["Stacks"][0]
     s3_client.head_bucket(Bucket=stack_description["Outputs"][0]["OutputValue"])
 
 
-@mock_s3
-@mock_cloudformation
+@mock_aws
 def test_s3_bucket_cloudformation_outputs():
     region_name = "us-east-1"
     s3_client = boto3.client("s3", region_name=region_name)
     cf_client = boto3.resource("cloudformation", region_name=region_name)
-    stack_name = "test-stack"
-    bucket_name = "test-bucket"
+    stack_name = str(uuid4())
+    bucket_name = str(uuid4())
     template = {
         "AWSTemplateFormatVersion": "2010-09-09",
         "Resources": {
