@@ -5,11 +5,11 @@ import boto3
 import pytest
 from botocore.client import ClientError
 
-from moto import mock_s3control
+from moto import mock_aws
 from tests.test_s3 import s3_aws_verified
 
 
-@mock_s3control
+@mock_aws
 def test_get_unknown_access_point():
     client = boto3.client("s3control", region_name="ap-southeast-1")
 
@@ -21,7 +21,7 @@ def test_get_unknown_access_point():
     assert err["AccessPointName"] == "ap_name"
 
 
-@mock_s3control
+@mock_aws
 def test_get_access_point_minimal():
     client = boto3.client("s3control", region_name="ap-southeast-1")
     client.create_access_point(
@@ -57,7 +57,7 @@ def test_get_access_point_minimal():
     )
 
 
-@mock_s3control
+@mock_aws
 def test_get_access_point_full():
     client = boto3.client("s3control", region_name="ap-southeast-1")
     client.create_access_point(
@@ -87,6 +87,40 @@ def test_get_access_point_full():
     }
 
 
+@mock_aws
+def test_list_access_points():
+    region = "us-east-1"
+    account_id = "111111111111"
+    client = boto3.client("s3control", region_name=region)
+    s3_client = boto3.client("s3", region_name=region)
+
+    resp = client.list_access_points(AccountId=account_id)
+    assert not resp.get("AccessPointList")
+
+    s3_client.create_bucket(Bucket="bucket-a")
+    s3_client.create_bucket(Bucket="bucket-b")
+    client.create_access_point(AccountId=account_id, Name="ap1-a", Bucket="bucket-a")
+    client.create_access_point(AccountId=account_id, Name="ap2-a", Bucket="bucket-a")
+    client.create_access_point(AccountId=account_id, Name="ap3-b", Bucket="bucket-b")
+
+    resp = client.list_access_points(AccountId=account_id)
+    assert len(resp["AccessPointList"]) == 3
+
+    resp = client.list_access_points(AccountId=account_id, Bucket="bucket-a")
+    aps = resp["AccessPointList"]
+    assert len(aps) == 2
+    assert {ap["Name"] for ap in aps} == {"ap1-a", "ap2-a"}
+
+    resp = client.list_access_points(AccountId=account_id, MaxResults=2)
+    assert len(resp["AccessPointList"]) == 2
+    assert "NextToken" in resp
+
+    next_token = resp["NextToken"]
+    resp2 = client.list_access_points(AccountId=account_id, NextToken=next_token)
+    assert len(resp2["AccessPointList"]) == 1
+    assert "NextToken" not in resp2
+
+
 @pytest.mark.aws_verified
 @s3_aws_verified
 def test_delete_access_point(bucket_name=None):
