@@ -2,6 +2,7 @@ import json
 
 import moto.server as server
 from moto import mock_aws
+from moto.utilities.constants import APPLICATION_AMZ_JSON_1_1
 
 
 @mock_aws
@@ -9,7 +10,10 @@ def test_textract_start_text_detection():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentTextDetection"}
+    headers = {
+        "X-Amz-Target": "Textract.StartDocumentTextDetection",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "DocumentLocation": {
             "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
@@ -26,7 +30,10 @@ def test_textract_start_text_detection():
 def test_detect_document_text():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.DetectDocumentText"}
+    headers = {
+        "X-Amz-Target": "Textract.DetectDocumentText",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "DocumentLocation": {
             "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
@@ -43,7 +50,10 @@ def test_textract_start_text_detection_without_document_location():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentTextDetection"}
+    headers = {
+        "X-Amz-Target": "Textract.StartDocumentTextDetection",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     resp = test_client.post("/", headers=headers, json={})
     data = json.loads(resp.data.decode("utf-8"))
     assert resp.status_code == 400
@@ -59,7 +69,10 @@ def test_textract_get_text_detection():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentTextDetection"}
+    headers = {
+        "X-Amz-Target": "Textract.StartDocumentTextDetection",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "DocumentLocation": {
             "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
@@ -69,7 +82,10 @@ def test_textract_get_text_detection():
     resp = test_client.post("/", headers=headers, json=request_body)
     start_job_data = json.loads(resp.data.decode("utf-8"))
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.GetDocumentTextDetection"}
+    headers = {
+        "X-Amz-Target": "Textract.GetDocumentTextDetection",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "JobId": start_job_data["JobId"],
     }
@@ -84,7 +100,10 @@ def test_textract_get_text_detection_without_job_id():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.GetDocumentTextDetection"}
+    headers = {
+        "X-Amz-Target": "Textract.GetDocumentTextDetection",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "JobId": "invalid_job_id",
     }
@@ -100,7 +119,10 @@ def test_textract_start_document_analysis():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentAnalysis"}
+    headers = {
+        "X-Amz-Target": "Textract.StartDocumentAnalysis",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "DocumentLocation": {
             "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
@@ -119,7 +141,10 @@ def test_textract_get_document_analysis():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentAnalysis"}
+    headers = {
+        "X-Amz-Target": "Textract.StartDocumentAnalysis",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "DocumentLocation": {
             "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
@@ -130,7 +155,10 @@ def test_textract_get_document_analysis():
     resp = test_client.post("/", headers=headers, json=request_body)
     start_job_data = json.loads(resp.data.decode("utf-8"))
 
-    headers = {"X-Amz-Target": "X-Amz-Target=Textract.GetDocumentAnalysis"}
+    headers = {
+        "X-Amz-Target": "Textract.GetDocumentAnalysis",
+        "Content-Type": APPLICATION_AMZ_JSON_1_1,
+    }
     request_body = {
         "JobId": start_job_data["JobId"],
     }
